@@ -5,7 +5,7 @@ import pandas as pd
 import os
 from time import sleep
 
-versionNo = "0.1.2"
+versionNo = "0.1.3"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -13,6 +13,39 @@ dataEndpoint = "tcp://127.0.0.1:5556"
 profilesPath = os.path.expanduser('~\\Documents\\Impulse\\Profiles\\')
 profilesPath = profilesPath.replace("\\","/")
 
+
+decimalVals = {
+    'temperatureMeasured': 6,
+    'temperatureSetpoint': 6,
+    'powerMeasured': 3,
+    'currentMeasured': 18,
+    'voltageMeasured': 15,
+    'setpoint': 18,
+    'resistance': 11,
+    'compliance': 18,
+    'gas1FlowMeasured': 9,
+    'gas2FlowMeasured': 9,
+    'gas3FlowMeasured': 9,
+    'gas1ConcentrationMeasured': 2,
+    'gas2ConcentrationMeasured': 2,
+    'gas3ConcentrationMeasured': 2,
+    'gas1FlowSetpoint': 9,
+    'gas2FlowSetpoint': 9,
+    'gas3FlowSetpoint': 9,
+    'gas1ConcentrationSetpoint': 2,
+    'gas2ConcentrationSetpoint': 2,
+    'inletPressureMeasured': 7,
+    'outletPressureMeasured': 7,
+    'inletPressureSetpoint': 7,
+    'outletPressureSetpoint': 7,
+    'reactorPressureMeasured': 7,
+    'reactorFlowMeasured': 9,
+    'reactorPressureSetpoint': 7,
+    'reactorFlowSetpoint': 9,
+    'vacuumPressureMeasured': 9,
+    'flowCheckSetpoint': 9,
+}
+
 def version():
     return versionNo
 
@@ -393,47 +426,19 @@ class dataHandler():
         self.event.set()
 
 
-    def roundDataFrame(self, dataSet):
-        decimalVals = {
-            'temperatureMeasured': 6,
-            'temperatureSetpoint': 6,
-            'powerMeasured': 3,
-            'currentMeasured': 18,
-            'voltageMeasured': 15,
-            'setpoint': 18,
-            'resistance': 11,
-            'compliance': 18,
-            'gas1FlowMeasured': 9,
-            'gas2FlowMeasured': 9,
-            'gas3FlowMeasured': 9,
-            'gas1ConcentrationMeasured': 2,
-            'gas2ConcentrationMeasured': 2,
-            'gas3ConcentrationMeasured': 2,
-            'gas1FlowSetpoint': 9,
-            'gas2FlowSetpoint': 9,
-            'gas3FlowSetpoint': 9,
-            'gas1ConcentrationSetpoint': 2,
-            'gas2ConcentrationSetpoint': 2,
-            'inletPressureMeasured': 7,
-            'outletPressureMeasured': 7,
-            'inletPressureSetpoint': 7,
-            'outletPressureSetpoint': 7,
-            'reactorPressureMeasured': 7,
-            'reactorFlowMeasured': 9,
-            'reactorPressureSetpoint': 7,
-            'reactorFlowSetpoint': 9,
-            'vacuumPressureMeasured': 9,
-            'flowCheckSetpoint': 9,
-            }
-        
+    def roundDataFrame(self, dataSet):       
         dataSet = dataSet.round(decimalVals)
         return dataSet
         
     def getLastData(self):
         if self.dataSock is not None:
             self.lastSentSequence = self.lastMssg["sequenceNumber"]
-            df = self.getDataFrame(-1)
-            return df
+            dataSet = self.lastMssg
+            for key, value in dataSet.items():
+                if key in decimalVals:
+                    dataSet[key]=round(dataSet[key],decimalVals[key])
+            return dataSet
+
         else:
             print(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
             return []
@@ -443,8 +448,11 @@ class dataHandler():
             while self.lastMssg["sequenceNumber"] == self.lastSentSequence:
                 sleep(0.001)
             self.lastSentSequence = self.lastMssg["sequenceNumber"]
-            df = self.getDataFrame(-1)
-            return df
+            dataSet = self.lastMssg
+            for key, value in dataSet.items():
+                if key in decimalVals:
+                    dataSet[key]=round(dataSet[key],decimalVals[key])
+            return dataSet
         else:
             print(f"[ALERT] Please subscribe using impulse.{self.topic}.data.subscribe() first")
             return []
